# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a sample from the 'Hack the Badge' workshop

Implementation Notes
--------------------
**Hardware:**
    * one of the Explorer Badge designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries

**Open Source Repository:**
    * GitLab: https://gitlab.com/bradanlane/exp_tutorial
    
'''

import time
import board
import neopixel
import touchio


''' setup the Neopixel LEDs '''
NEOPIXEL_COUNT: int = 9
leds = neopixel.NeoPixel(board.NEOPIXEL, NEOPIXEL_COUNT, brightness=0.15, auto_write=True)

# lets quickly cycle all the neopixels through a range of colors
colors: list = [0x0000FF, 0x00FF00, 0x00FFFF, 0xFF0000, 0xFF00FF, 0xFFFF00, 0xFFFFFF, 0x000000]
COLOR_COUNT: int = 8
color_index: int = 0

''' setup the capacitive touch sensors '''
TOUCH_PINS: list = [board.TOUCH1, board.TOUCH2, board.TOUCH3, board.TOUCH4, board.TOUCH5, board.TOUCH6, board.TOUCH7, board.TOUCH8, board.TOUCH9]
TOUCH_COUNT:int = 9

touch_sensors = [None for i in range(TOUCH_COUNT)]	# start with a list of `None` data
for i in range(TOUCH_COUNT):
    touch_sensors[i] = touchio.TouchIn(TOUCH_PINS[i])
    # the minimum sensitivity (aka threshold) is set when the touch sensor is created
    print(f"initialized touch {i:d} with threshold {touch_sensors[i].threshold:d}")

try:
    while True:
        for i in range(TOUCH_COUNT):
            if touch_sensors[i].value:  # teh raw touch value is greater that the threshold value
                leds[i] = 0x00FF00
                print(f"touch #{i:d} has a value of {touch_sensors[i].raw_value:d}")
                pass
            else:
                leds[i] = 0x000000
                pass

        time.sleep(0.05)

finally:
    leds.fill(0x000000)
